@@ -1,9 +1,5 @@
 from __future__ import absolute_import, unicode_literals
-from mongoengine import StringField, IntField, BooleanField, \
-                        DateTimeField, ListField, FloatField,\
-                        EmbeddedDocumentField, EmbeddedDocumentListField, \
-                        DictField, EmbeddedDocument, connect \
-
+from mongoengine import connect
 from mongoengine.connection import disconnect
 import os
 from celery import Celery
@@ -29,12 +25,15 @@ class CelerySettings():
     def __init__(self, broker_url=None, temp_celery_folder=None, proj_name=None):
         self.celery_broker = broker_url if broker_url!=None else os.environ.get("REDIS_URL", "redis://redis:6379/1")
         self.temp_folder = temp_celery_folder if temp_celery_folder!=None else os.environ.get("TEMP_CELERY_FOLDER", "/tmp/celery-linter")
-        self.proj_name = proj_name if proj_name!=Name else os.environ.get("CELERY_PROJECT_NAME", "topo_celery_proj")
+        self.proj_name = proj_name if proj_name!=None else os.environ.get("CELERY_PROJECT_NAME", "topo_celery_proj")
         self.app = Celery(self.proj_name, broker=self.celery_broker, backend=self.celery_broker)
 
     def get_app(self):
         return self.app
 
+    def get_temp_folder(self):
+        return self.temp_folder
+
     def add_autodiscover(self, task_name):
         self.app.autodiscover_tasks([
             task_name
